@@ -1,9 +1,11 @@
 package App::ClipboardUtils;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-15'; # DATE
+our $DATE = '2022-10-09'; # DATE
 our $DIST = 'App-ClipboardUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: CLI utilities related to clipboard
@@ -20,7 +22,7 @@ App::ClipboardUtils - CLI utilities related to clipboard
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ClipboardUtils (from Perl distribution App-ClipboardUtils), released on 2021-07-15.
+This document describes version 0.003 of App::ClipboardUtils (from Perl distribution App-ClipboardUtils), released on 2022-10-09.
 
 =head1 DESCRIPTION
 
@@ -28,6 +30,10 @@ This distribution contains the following CLI utilities related to clipboard:
 
 =over
 
+=item * L<add-clipboard-content>
+
+=item * L<clear-clipboard-content>
+
 =item * L<clear-clipboard-history>
 
 =item * L<detect-clipboard-manager>
@@ -46,6 +52,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Clipbo
 
 Source repository is at L<https://github.com/perlancar/perl-App-ClipboardUtils>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ClipboardUtils>
@@ -54,15 +89,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
